@@ -110,6 +110,34 @@ class TkeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CheckInstancesUpgradeAble(self, request):
+        """This API is used to check which nodes can be upgraded in the given node list.
+
+        :param request: Request instance for CheckInstancesUpgradeAble.
+        :type request: :class:`tencentcloud.tke.v20180525.models.CheckInstancesUpgradeAbleRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.CheckInstancesUpgradeAbleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CheckInstancesUpgradeAble", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CheckInstancesUpgradeAbleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateCluster(self, request):
         """This API is used to create a cluster.
 
@@ -1139,6 +1167,34 @@ class TkeClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpgradeClusterInstances(self, request):
+        """This API is used to upgrade one or more work nodes in the cluster.
+
+        :param request: Request instance for UpgradeClusterInstances.
+        :type request: :class:`tencentcloud.tke.v20180525.models.UpgradeClusterInstancesRequest`
+        :rtype: :class:`tencentcloud.tke.v20180525.models.UpgradeClusterInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpgradeClusterInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpgradeClusterInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
